@@ -1,7 +1,7 @@
 /* 
    Project: batmon
 
-   Copyright (C) 2005-2008 GNUstep Application Project
+   Copyright (C) 2005-2009 GNUstep Application Project
 
    Author: Riccardo Mottola
    FreeBSD support by Chris B. Vetter
@@ -65,7 +65,10 @@
 	font = [NSFont systemFontOfSize:9.0];
 	stateStrAttributes = [[NSDictionary dictionaryWithObjectsAndKeys:
         font, NSFontAttributeName,
+	[NSColor blueColor], NSForegroundColorAttributeName,
         style, NSParagraphStyleAttributeName, nil] retain];
+        iconPlug = [[NSImage imageNamed:@"small_plug.tif"] retain];
+        iconBattery = [[NSImage imageNamed:@"small_battery.tif"] retain];
     }
     return self;
 }
@@ -109,6 +112,11 @@
   return NO;
 }
 
+- (IBAction)showMonitor:(id)sender
+{
+  [monitorWin makeKeyAndOrderFront:nil];
+}
+
 - (void)showPrefPanel:(id)sender
 {
 }
@@ -120,37 +128,48 @@
 
 }
 
-#define HEIGHT 47
+#define HEIGHT 42
 #define WIDTH  20
 - (void)drawImageRep
 {
-    NSBezierPath *bzp;
     NSMutableString *str;
-    char *cStr;
+    char cStr[5];
     float chargePercentToDraw; /* we need this beause chargePercent can go beyond 100% */
+    NSImage *chargeStatusIcon;
+
+    if ([batModel isCharging])
+      chargeStatusIcon = iconPlug;
+    else
+      chargeStatusIcon = iconBattery;
+
+    [chargeStatusIcon compositeToPoint: NSMakePoint(WIDTH+6, HEIGHT-15) operation:NSCompositeSourceOver];
 
     chargePercentToDraw = [batModel chargePercent];
     if (chargePercentToDraw > 100)
         chargePercentToDraw = 100;
 
-    [[NSColor blackColor] set];
-    bzp = [NSBezierPath bezierPath];
-    [bzp appendBezierPathWithRect: NSMakeRect(0, 1, WIDTH, HEIGHT)];
-    [bzp stroke];
+    [[NSColor darkGrayColor] set];
+    /* main body */
+    [NSBezierPath strokeRect: NSMakeRect(0, 1, WIDTH, HEIGHT)];
+    /* top nib */
+    [NSBezierPath strokeRect: NSMakeRect((WIDTH/2)-3, HEIGHT+1, 6, 4)];
+
+    [[NSColor grayColor] set];
+    /* right light shadow */
+    [NSBezierPath strokeLineFromPoint:NSMakePoint(WIDTH+1, 0) toPoint:NSMakePoint(WIDTH+1, HEIGHT-1)];
+    /* nib filler */
+    [NSBezierPath fillRect: NSMakeRect((WIDTH/2)-2, HEIGHT+1+1, 4, 2)];
     
-    bzp = [NSBezierPath bezierPath];
-    if ([batModel remainingCapacity] < [batModel warningCapacity])
+    /* draw the charge status */
+    if ([batModel isCritical] == YES)
        [[NSColor redColor] set];
     else
-       [[NSColor whiteColor] set];
-    [bzp appendBezierPathWithRect: NSMakeRect(0+1, 1+1, WIDTH - 2, (chargePercentToDraw/100) * HEIGHT -2)];
-    [bzp fill];
+       [[NSColor greenColor] set];
+    [NSBezierPath fillRect: NSMakeRect(0+1, 1, WIDTH-1, (chargePercentToDraw/100) * HEIGHT -2)];
 
-    cStr = calloc(4, sizeof(char));
     sprintf(cStr, "%2.0f%%", [batModel chargePercent]);
     str = [NSMutableString stringWithCString:cStr];
     [str drawAtPoint: NSMakePoint(WIDTH + 5 , 1) withAttributes:stateStrAttributes];
-    free(cStr);
 }
 
 - (void)drawIcon
